@@ -116,6 +116,7 @@ def invoke_backend_service_as_proxy(request, method, function_path, json_data=di
             response_data = response.read()
             conn.close()
 
+            response_json = None
             try:
                 response_json = json.loads(response_data)
             except:
@@ -139,8 +140,8 @@ def invoke_backend_service_as_proxy(request, method, function_path, json_data=di
                 for header, value in response.getheaders():
                     resp[header] = value
 
-                if not resp.has_header(proxy_server.CSRF_TOKEN):
-                    resp[proxy_server.CSRF_TOKEN] = get_token(request)
+                '''if not resp.has_header(proxy_server.CSRF_TOKEN):
+                    resp[proxy_server.CSRF_TOKEN] = get_token(request)'''
 
                 return resp
             else:
